# All-in-one Static Hello World Sample

This sample project provides an all-one-one package demo for the Hello World sample described in the [wiki](https://github.com/swagger-api/swagger-spec/wiki/Hello-World-Sample).

## Requirements

This samples requires Java 5 or above and [Maven](http://maven.apache.org) installed.

## Run the sample

In your favorite command-line, run:

```
mvn jetty:run
```

Then in your favorite web browser, open:
```
http://localhost:8000
```
